/*
 * $Header: /home/cvspublic/jakarta-commons/resources/src/java/org/apache/commons/resources/ResourcesFactory.java,v 1.11 2004/03/27 21:34:10 dgraham Exp $
 * $Revision: 1.11 $
 * $Date: 2004/03/27 21:34:10 $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources;

import java.io.Serializable;

/**
 * <a>A {@link org.apache.commons.resources.ResourcesFactory} 
 * is a factory pattern interface for a
 * class that can create {@link org.apache.commons.resources.Resources} 
 * instances based on a logical
 * name that is passed to the factory.  Repeated requests to return a
 * {@link org.apache.commons.resources.Resources} instance with the same 
 * name should return the same
 * {@link org.apache.commons.resources.Resources} instance each time.</p>
 *
 * <p>Implementations of {@link org.apache.commons.resources.ResourcesFactory} 
 * <strong>MUST</strong>
 * include a zero-arguments constructor so that instances of the factory
 * can be dynamically created.  Therefore, configuration information
 * above and beyond the configuration String will generally be specified
 * via JavaBeans property setters on the 
 * {@link org.apache.commons.resources.ResourcesFactory}
 * implementation class.</p>
 */
public interface ResourcesFactory extends Serializable {
    

    // ------------------------------------------------------------- Properties


    /**
     * <p>Return the <code>returnNull</code> property value that will be
     * configured on {@link org.apache.commons.resources.Resources} 
     * instances created by this factory.</p>
     */
    public boolean isReturnNull();


    /**
     * <p>Set the <code>returnNull</code> property value that will be configured on 
     * {@link org.apache.commons.resources.Resources} instances created by this 
     * factory.</p>
     *
     * @param returnNull The new value to delegate
     */
    public void setReturnNull(boolean returnNull);


    // --------------------------------------------------------- Public Methods


    /**
     * <p>Create (if necessary) and return a 
     * {@link org.apache.commons.resources.Resources} instance
     * for the specified logical name, with a default configuration.</p>
     *
     * @param name Logical name of the 
     * {@link org.apache.commons.resources.Resources} instance to
     *  be returned
     *
     * @exception ResourcesException if a 
     * {@link org.apache.commons.resources.Resources} instance
     *  of the specified logical name cannot be returned.
     */
    public Resources getResources(String name)
        throws ResourcesException;


    /**
     * <p>Create (if necessary) and return a 
     * {@link org.apache.commons.resources.Resources} instance
     * for the specified logical name, with a configuration based on
     * the specified configuration String.</p>
     *
     * @param name Logical name of the 
     * {@link org.apache.commons.resources.Resources} instance to be returned
     * @param config Configuration string for this resource (meaning
     *  is dependent upon the {@link org.apache.commons.resources.ResourcesFactory} 
     * implementation being utilized), or <code>null</code> for the default
     *  configuration
     *
     * @exception ResourcesException if a 
     * {@link org.apache.commons.resources.Resources} instance
     *  of the specified logical name cannot be returned.
     */
    public Resources getResources(String name, String config)
        throws ResourcesException;


    /**
     * <p>Release any internal references to 
     * {@link org.apache.commons.resources.Resources} instances
     * that have been returned previously, after calling the
     * <code>destroy()</code> method of each such instance.</p>
     *
     * @exception ResourcesException if an error occurs while releasing
     */
    public void release() throws ResourcesException;


}
