/*
 * $Header: /home/cvspublic/jakarta-commons/resources/src/java/org/apache/commons/resources/impl/JDBCResourcesFactory.java,v 1.1 2004/06/11 02:43:48 jmitchell Exp $
 * $Revision: 1.1 $
 * $Date: 2004/06/11 02:43:48 $
 *
 * ====================================================================
 *
 *  Copyright 2003-2004 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import org.apache.commons.resources.Resources;
import org.apache.commons.resources.ResourcesException;

/**
 * <p>Concrete implementation of 
 * {@link org.apache.commons.resources.ResourcesFactory} that creates
 * {@link org.apache.commons.resources.Resources} instances that wraps 
 * a JDBC database connection and retrieves values for the given 
 * <code>Locale</code> and have name suffixes reflecting the 
 * <code>Locale</code> for which the document's messages apply.
 * For this specific implementation, resources are looked up in 
 * a hierarchy of database values in a manner identical to that 
 * performed by <code>java.util.ResourceBundle.getBundle().</code>.
 *
 * @author James Mitchell
 * @version $Revision: 1.1 $
 */
public class JDBCResourcesFactory extends ResourcesFactoryBase {


    // ------------------------------------------------------ Protected Methods


    /**
     * <p>Create and return a new {@link org.apache.commons.resources.Resources} 
     * instance with the specified logical name, after calling its <code>init()</code>
     * method and delegating the relevant properties.</p>
     *
     * @param name Logical name of the {@link org.apache.commons.resources.Resources} 
     * instance to create
     * 
     * @param config Configuration string for this resource (if any)
     *
     * @exception ResourcesException if a {@link org.apache.commons.resources.Resources} 
     * instance of the specified logical name cannot be created.
     */
    protected Resources createResources(String name, String config)
        throws ResourcesException {

        Resources res = new JDBCResources(name, config);
        res.setReturnNull(isReturnNull());
        res.init();
        return (res);

    }


}
